# ------------------------------------------------------------------------------
# Makefile-template for gendist
#
# This is the template for initrd.inc. This makefile contains rules
# for creating a compressed initial ramdisk.
#
# $Author: Bablokb $
# $Revision: 1.20 $
#
# License: GPL2 (see COPYING)
# ------------------------------------------------------------------------------

sed -e "s!@DIST_NAME@!$1!g" \
    -e "s/@version@/$version/g" << "EOF"
# -----------------------------------------------------------------------------
# Makefile-include for @DIST_NAME@
#
# Automatically generated by GENDIST.
#
# This makefile contains rules for creating a compressed initial ramdisk.
# This makefile is included by makefiles in media/Makefile.*
#
# License: GPL2
# -----------------------------------------------------------------------------

ifeq (,$(CURRENT_FS))
  CURRENT_FS := root-fs
endif
ifeq (,$(INITRD))
  INITRD      := $(BUILD_DIR)/initrd
endif
ifeq (,$($(CURRENT_FS)_DIR))
  $(CURRENT_FS)_DIR = $(BUILD_DIR)/$(CURRENT_FS)
endif

INITRD_MNT  := $(BUILD_DIR)/mnt.initrd.$(CURRENT_FS)
NODE_COUNT  := $(BUILD_DIR)/rd-nodes.$(CURRENT_FS)
BLOCK_COUNT := $(BUILD_DIR)/rd-blocks.$(CURRENT_FS)
BPERG_COUNT := $(BUILD_DIR)/rd-blocks-per-group.$(CURRENT_FS)

.PHONY: initrd

initrd: $(INITRD).gz

$(INITRD).gz: $(NODE_COUNT) $(BLOCK_COUNT) $(BPERG_COUNT)
	mkdir -p $(BUILD_DIR)
	dd if=/dev/zero of=$(INITRD) count=`cat $(BLOCK_COUNT)` bs=1k
	mkdir -p $(INITRD_MNT)
ifeq (minix,$(RD_FS))
	mkfs.minix -i `cat $(NODE_COUNT)` $(INITRD)
else
	mkfs.ext2 -FN `cat $(NODE_COUNT)` -g `cat $(BPERG_COUNT)` $(INITRD)
endif
	mount -o loop $(INITRD) $(INITRD_MNT)
ifeq (ext2,$(RD_FS))
	rm -fr $(INITRD_MNT)/lost+found
endif
	tar -cpf - -C $($(CURRENT_FS)_DIR) . | tar -xpf - -C $(INITRD_MNT) || { \
	  echo "error: no space left on filesystem!"; \
	  umount $(INITRD_MNT); \
	  exit 1; \
	}
	umount $(INITRD_MNT)
	gzip -9fn $(INITRD)

$(NODE_COUNT):
	$(MAKE) -C $(DIST_ROOT) $(CURRENT_FS)   # prevents excessive rebuilding
ifeq (auto,$(RD_NODES))
	echo $$[`ls -1R $($(CURRENT_FS)_DIR) | wc -l`+$(RD_NODES_INC)] > $(NODE_COUNT)
else
	echo $(RD_NODES) > $(NODE_COUNT)
endif

$(BLOCK_COUNT): $(NODE_COUNT)
ifeq (auto,$(RD_SIZE))
	let b=`du -sck $($(CURRENT_FS)_DIR)/* |tail -1 | cut -f1`+$(RD_SIZE_INC); \
	let b+=$$(( (`cat $(NODE_COUNT)`-1)/8+1 )); \
	echo $$b > $(BLOCK_COUNT)
else
	echo $(RD_SIZE) > $(BLOCK_COUNT)
endif

# we can have 8192 inodes per group, so we divide blocks by needed groups
# finally, blocks-per-group must be a multiple of 8 and not larger than 8192

$(BPERG_COUNT): $(BLOCK_COUNT) $(NODE_COUNT)
	let pberg=$$(( `cat $(BLOCK_COUNT)`/((`cat $(NODE_COUNT)`-1)/8192+1) )); \
	let pberg-=pberg%8; [ $$pberg -gt 8192 ] && let pberg=8192; \
	echo $$pberg > $(BPERG_COUNT)
EOF