# -----------------------------------------------------------------------------
# Makefile-template for gendist
#
# This is the template for the standard rules of package-level makefiles
#
# $Author: Bablokb $
# $Revision: 1.27 $
#
# License: GPL2 (see COPYING)
# -----------------------------------------------------------------------------

sed -e "s!@DIST_NAME@!$1!g" \
    -e "s/@version@/$version/g" << "EOF"
# -----------------------------------------------------------------------------
# Makefile for @DIST_NAME@
#
# Automatically generated by GENDIST.
#
# Standard rules for package-level makefiles
#
# License: GPL2
# -----------------------------------------------------------------------------

.PHONY: install clean distclean mrproper

TARGET      := _$(shell basename `pwd`).install
DEP-TARGETS := $(join $(DEP-PACKAGES), \
                      $(patsubst %,/_%.install,$(notdir $(DEP-PACKAGES))))

ifeq (install,$(MAKECMDGOALS))
ifeq (/,$(TARGET_DIR))
$(error Cowardly refusing to build package with TARGET_DIR=/!)
endif
ifeq (,$(TARGET_DIR))
$(error Cowardly refusing to build package with empty TARGET_DIR!)
endif
endif

TARGET-ENV      := _$(shell basename `pwd`).env-install
DEP-TARGETS-ENV := $(join $(DEP-PACKAGES-ENV), \
                   $(patsubst %,/_%.env-install,$(notdir $(DEP-PACKAGES-ENV))))

ifeq (env-install,$(MAKECMDGOALS))
ifeq (/,$(TARGET_DIR))
$(error Cowardly refusing to build package with TARGET_DIR=/!)
endif
ifeq (,$(TARGET_DIR))
$(error Cowardly refusing to build package with empty TARGET_DIR!)
endif
endif

ifeq (true,$(DONT_USE_ENV_PATH))
export PATH := $(subst $(ENV_DIR)/bin:,,$(PATH))
endif


# -----------------------------------------------------------------------------

# Pseudo-targets for install/env-install
# The targets "install" and "env-install" have to be defined 
# individually in each package-level makefile (these targets do the real stuff)

$(TARGET): $(DEP-TARGETS)
	$(MAKE) install         # don't make it a prereq, since it's phony
	touch $(TARGET)

$(TARGET-ENV): $(DEP-TARGETS-ENV)
	$(MAKE) env-install     # don't make it a prereq, since it's phony
	touch $(TARGET-ENV)

$(DEP-TARGETS):
	make -C $(@D) $(@F)

$(DEP-TARGETS-ENV):
	make -C $(@D) $(@F)

# -----------------------------------------------------------------------------

# variables defining clean/distclean/mrproper-targets
# override these variables to change the default behaviour

ifndef CLEAN_TARGETS
CLEAN_TARGETS := clean-default
endif

ifndef DISTCLEAN_TARGETS
DISTCLEAN_TARGETS := distclean-default
endif

ifndef MRPROPER_TARGETS
MRPROPER_TARGETS := mrproper-default
endif

# cleaning --------------------------------------------------------------------

clean: $(CLEAN_TARGETS)
	-rm -f $(TARGET)

clean-default: $(if $(PACKAGE_NAME),clean-source)

distclean: $(DISTCLEAN_TARGETS)

distclean-default: $(if $(PACKAGE_NAME),distclean-source) clean

mrproper: $(MRPROPER_TARGETS)

mrproper-default: $(if $(PACKAGE_NAME),mrproper-source) distclean

# environment-cleaning --------------------------------------------------------

ifndef ENV_CLEAN_TARGETS
ENV_CLEAN_TARGETS := env-clean-default
endif

ifndef ENV_DISTCLEAN_TARGETS
ENV_DISTCLEAN_TARGETS := env-distclean-default
endif

ifndef ENV_MRPROPER_TARGETS
ENV_MRPROPER_TARGETS := env-mrproper-default
endif

env-clean: $(ENV_CLEAN_TARGETS)
	rm -f $(TARGET-ENV)

env-clean-default: $(if $(PACKAGE_NAME),clean-source)

env-distclean: $(ENV_DISTCLEAN_TARGETS)
	rm -f $(TARGET-ENV)

env-distclean-default: $(if $(PACKAGE_NAME),distclean-source) env-clean

env-mrproper: $(ENV_MRPROPER_TARGETS)
	rm -f $(TARGET-ENV)

env-mrproper-default: $(if $(PACKAGE_NAME),mrproper-source) env-distclean

# building packages from source -----------------------------------------------

# example package definition:

#PACKAGE_NAME       := busybox
#PACKAGE_VERSION    := 0.60.3
#PACKAGE_EXT        := tar.bz2
#PACKAGE_WEB_PREFIX := http://busybox.net/downloads

.PHONY: unpack-package source clean-source distclean-source \
	unpack-package-default source-default clean-source-default \
	distclean-source-default 

ifndef $(PACKAGE_FILE)
PACKAGE_FILE    := $(PACKAGE_NAME)-$(PACKAGE_VERSION).$(PACKAGE_EXT)
endif
PACKAGE_SOURCE  := $(SOURCE_CACHE_DIR)/$(PACKAGE_FILE)
PATCH-TARGET    := _$(PACKAGE_NAME).patched
PACKAGE_SRC_DIR := $(SRC_DIR)/$(PACKAGE_NAME)

ifeq (true,$(USE_LOCAL_WEB))
SOURCE_WEB := $(LOCAL_WEB_PREFIX)/$(PACKAGE_FILE)
else
SOURCE_WEB := $(PACKAGE_WEB_PREFIX)/$(PACKAGE_FILE)
endif

# download --------------------------------------------------------------------

ifndef DOWNLOAD_TARGETS
DOWNLOAD_TARGETS := download-package-default
endif

$(PACKAGE_SOURCE): 
	$(MAKE) download

download: $(DOWNLOAD_TARGETS)

download-package-default:
	mkdir -p $(SOURCE_CACHE_DIR)
	cd $(SOURCE_CACHE_DIR) && wget -nd $(SOURCE_WEB)


# unpacking -------------------------------------------------------------------

TARGET-UNPACK := _$(shell basename `pwd`).unpack
ifndef UNPACK_TARGETS
UNPACK_TARGETS := unpack-package-default
endif

$(TARGET-UNPACK): $(PACKAGE_SOURCE)
	$(MAKE) unpack-package
	touch $(TARGET-UNPACK)

unpack-package: $(UNPACK_TARGETS)

ifndef UNPACK_CMD

ifeq ($(PACKAGE_EXT),tar.bz2)
UNPACK_CMD := tar -xjp -C $(PACKAGE_SRC_DIR).tmp -f
endif

ifeq ($(PACKAGE_EXT),tbz2)
UNPACK_CMD := tar -xjp -C $(PACKAGE_SRC_DIR).tmp -f
endif

ifeq ($(PACKAGE_EXT),tbz)
UNPACK_CMD := tar -xjp -C $(PACKAGE_SRC_DIR).tmp -f
endif

ifeq ($(PACKAGE_EXT),tar.gz)
UNPACK_CMD := tar -xzp -C $(PACKAGE_SRC_DIR).tmp -f
endif

ifeq ($(PACKAGE_EXT),tgz)
UNPACK_CMD := tar -xzp -C $(PACKAGE_SRC_DIR).tmp -f
endif

ifeq ($(PACKAGE_EXT),zip)
UNPACK_CMD := unzip -d $(PACKAGE_SRC_DIR).tmp
endif

endif	# UNPACK_CMD

unpack-package-default:
ifndef UNPACK_CMD
	@echo Unknown package format. Specify UNPACK_CMD in Makefile && exit 1
else
	@if [ -d $(PACKAGE_SRC_DIR).tmp ]; then \
	  rm -fr $(PACKAGE_SRC_DIR).tmp; \
	 fi
	mkdir -p $(PACKAGE_SRC_DIR).tmp;
	$(UNPACK_CMD) $(PACKAGE_SOURCE)
	@if [ -d $(PACKAGE_SRC_DIR).tmp/$(PACKAGE_NAME)-$(PACKAGE_VERSION) ]; then \
	  mv \
	   $(PACKAGE_SRC_DIR).tmp/$(PACKAGE_NAME)-$(PACKAGE_VERSION) \
	   $(SRC_DIR); \
	elif [ -d $(PACKAGE_SRC_DIR).tmp/$(PACKAGE_NAME) ]; then \
	  mv $(PACKAGE_SRC_DIR).tmp/$(PACKAGE_NAME) \
	   $(SRC_DIR)/$(PACKAGE_NAME)-$(PACKAGE_VERSION); \
	else \
	  mkdir -p $(SRC_DIR)/$(PACKAGE_NAME)-$(PACKAGE_VERSION); \
	  cd $(PACKAGE_SRC_DIR).tmp; \
	  mv `ls -A1` $(SRC_DIR)/$(PACKAGE_NAME)-$(PACKAGE_VERSION); \
	fi
	rm -fr $(PACKAGE_SRC_DIR).tmp
	ln -sf $(PACKAGE_NAME)-$(PACKAGE_VERSION) $(PACKAGE_SRC_DIR)
endif

# patching --------------------------------------------------------------------

TARGET-PATCH := _$(shell basename `pwd`).patch
ifndef PATCH_TARGETS
PATCH_TARGETS := patch-package-default
endif

$(TARGET-PATCH): $(TARGET-UNPACK)
	$(MAKE) patch-package
	touch $(TARGET-PATCH)

patch-package: $(PATCH_TARGETS)

patch-package-default:
	@if [ -x patch.sh ]; then \
	 ./patch.sh $(PACKAGE_SRC_DIR); \
	fi

# creating source -------------------------------------------------------------

source: $(TARGET-PATCH)

# cleaning packages -----------------------------------------------------------

ifndef CLEAN_SOURCE_TARGETS
CLEAN_SOURCE_TARGETS := clean-source-default
endif

clean-source: $(CLEAN_SOURCE_TARGETS)
	rm -f $(TARGET-PATCH)

clean-source-default:
	[ -d $(PACKAGE_SRC_DIR) ] && $(MAKE) -C $(PACKAGE_SRC_DIR) clean || :

# distcleaning packages -------------------------------------------------------

ifndef DISTCLEAN_SOURCE_TARGETS
DISTCLEAN_SOURCE_TARGETS := distclean-source-default
endif

distclean-source: $(DISTCLEAN_SOURCE_TARGETS)
	rm -f $(TARGET-PATCH) $(TARGET-UNPACK)

distclean-source-default:
ifneq (,$(filter $(DIST_ROOT)/%,$(SOURCE_CACHE_DIR)))
	rm -fr $(PACKAGE_SOURCE)     # remove only if relative to DIST_ROOT
endif
	rm -fr $(PACKAGE_SRC_DIR) $(PACKAGE_SRC_DIR)-$(PACKAGE_VERSION)

# mrproper packages -----------------------------------------------------------

ifndef MRPROPER_SOURCE_TARGETS
MRPROPER_SOURCE_TARGETS := mrproper-source-default
endif

mrproper-source: $(MRPROPER_SOURCE_TARGETS)
	rm -f $(TARGET-PATCH) $(TARGET-UNPACK)

mrproper-source-default:
	rm -fr $(PACKAGE_SOURCE)
	rm -fr $(PACKAGE_SRC_DIR) $(PACKAGE_SRC_DIR)-$(PACKAGE_VERSION)
EOF