# ------------------------------------------------------------------------------
# Makefile for gendist
#
# These are standard rules for the top-level makefile of a distribution
#
# $Author: Bablokb $
# $Revision: 1.26 $
#
# License: GPL2 (see COPYING)
# ------------------------------------------------------------------------------

sed -e "s!@DIST_NAME@!$1!g" \
    -e "s/@version@/$version/g" << "EOF"
# -----------------------------------------------------------------------------
# Makefile for @DIST_NAME@
#
# Automatically generated by GENDIST.
#
# These are standard rules for the top-level makefile of @DIST_NAME@
#
# License: GPL2
# -----------------------------------------------------------------------------

# target for targets within packages ------------------------------------------

# package, filesystem and target have to be passed on the commandline, e.g.:
# make package-target fs=root-fs package=foo target=build

package-target:
	$(MAKE) -C $(PACKAGE_DIR)/$(fs)/$(package) $(target)

# create src or bin archives of packages --------------------------------------

package-src-archive:
	rm -fr $(BUILD_DIR)/$(package).tmp
	mkdir -p $(BUILD_DIR)/$(package).tmp
	tar -cpf - -C $(PACKAGE_DIR)/$(fs)/ $(package) | \
	                             tar -xpf - -C $(BUILD_DIR)/$(package).tmp
	$(MAKE) -C $(BUILD_DIR)/$(package).tmp/$(package) distclean
	tar -cjpf $(DIST_NAME)-$(VERSION)-$(package)-src.tar.bz2 \
	                             -C $(BUILD_DIR)/$(package).tmp $(package)
	rm -fr $(BUILD_DIR)/$(package).tmp

package-bin-archive:
	rm -fr $(BUILD_DIR)/$(package).tmp
	mkdir -p $(BUILD_DIR)/$(package).tmp/$(fs)
	tar -cpf - -C $(PACKAGE_DIR)/$(fs)/ $(package) | \
	                             tar -xpf - -C $(BUILD_DIR)/$(package).tmp
	$(MAKE) -C $(BUILD_DIR)/$(package).tmp/$(package) install \
	                       TARGET_DIR=$(BUILD_DIR)/$(package).tmp/$(fs)
	tar -cjpf $(DIST_NAME)-$(VERSION)-$(package)-bin.tar.bz2 \
	                                -C $(BUILD_DIR)/$(package).tmp/$(fs) .
	rm -fr $(BUILD_DIR)/$(package).tmp



# targets (for cleanup and building the distribution) -------------------------

.PHONY: clean distclean mrproper \
        src-dist bin-dist \
        inc-dist-major inc-dist-minor inc-dist-pl

clean: $(FILESYSTEMS:%=clean-%)
	rm -fr $(DIST_NAME)-*.tar.bz2
	@if [ -d $(BUILD_DIR) ]; then \
	  cd $(BUILD_DIR); \
	  ls -A1 | grep -v env | xargs -t rm -fr; \
	fi

distclean: env-distclean $(FILESYSTEMS:%=distclean-%)
	rm -fr $(BUILD_DIR) $(DIST_NAME)-*.tar.bz2

mrproper: $(FILESYSTEMS:%=mrproper-%)
	rm -fr $(BUILD_DIR) $(DIST_NAME)-*.tar.bz2

src-dist:
	rm -f $(DIST_NAME).tgz $(DIST_NAME)-$(VERSION)-src.tar.bz2
	tar -czf $(DIST_NAME).tgz --exclude "CVS" $(DIST_STUFF) $(SRC_ADD)
	rm -fr $(DIST_NAME)-$(VERSION)
	mkdir $(DIST_NAME)-$(VERSION)
	(cd $(DIST_NAME)-$(VERSION); \
		tar -xzf ../$(DIST_NAME).tgz; $(MAKE) distclean)
	tar -cpjf $(DIST_NAME)-$(VERSION)-src.tar.bz2 $(DIST_NAME)-$(VERSION)
	rm -fr $(DIST_NAME)-$(VERSION) $(DIST_NAME).tgz

bin-dist: media
	rm -f $(DIST_NAME).tgz $(DIST_NAME)-$(VERSION)-bin.tar.bz2
	tar -czf $(DIST_NAME).tgz --exclude "CVS" $(DIST_STUFF) $(BIN_ADD) \
							   -C $(MEDIA_DIR) .
	rm -fr $(DIST_NAME)-$(VERSION)
	mkdir $(DIST_NAME)-$(VERSION)
	(cd $(DIST_NAME)-$(VERSION); tar -xzf ../$(DIST_NAME).tgz)
	tar -cpjf $(DIST_NAME)-$(VERSION)-bin.tar.bz2 $(DIST_NAME)-$(VERSION)
	rm -fr $(DIST_NAME)-$(VERSION) $(DIST_NAME).tgz

inc-dist-major:
	@echo DIST_MAJOR=$$[$(DIST_MAJOR)+1] > version.inc
	@echo DIST_MINOR=0 >> version.inc
	@echo DIST_PL=0 >> version.inc
	@cat version.inc

inc-dist-minor:
	@echo DIST_MAJOR=$(DIST_MAJOR) > version.inc
	@echo DIST_MINOR=$$[$(DIST_MINOR)+1] >> version.inc
	@echo DIST_PL=0 >> version.inc
	@cat version.inc

inc-dist-pl:
	@echo DIST_MAJOR=$(DIST_MAJOR) > version.inc
	@echo DIST_MINOR=$(DIST_MINOR) >> version.inc
	@echo DIST_PL=$$[$(DIST_PL)+1] >> version.inc
	@cat version.inc
EOF